@@ -2,7 +2,7 @@ use super::*;
 
 #[test]
 fn basic_cases() {
-    let map = MapxRkMk::new(4);
+    let map = MapxRawKeyMk::new(4);
 
     // key size mismatch
     assert!(map.insert(&[&[1]], &0u32).is_err());
